@@ -14,3 +14,8 @@ generics::fit_xy
 #' @importFrom generics tidy
 #' @export
 generics::tidy
+
+
+#' @importFrom generics glance
+#' @export
+generics::glance
