@@ -8,11 +8,13 @@ library(dplyr)
 
 context("keras logistic regression")
 source("helpers.R")
+source(test_path("helper-objects.R"))
+hpc <- hpc_data[1:150, c(2:5, 8)]
 
 # ------------------------------------------------------------------------------
 
 set.seed(352)
-dat <- iris[order(runif(nrow(iris))),]
+dat <- hpc[order(runif(150)),]
 
 tr_dat <- dat[1:140, ]
 te_dat <- dat[141:150, ]
@@ -42,7 +44,7 @@ test_that('model fitting', {
         basic_mod,
         control = ctrl,
         x = tr_dat[, -5],
-        y = tr_dat$Species
+        y = tr_dat$class
       ),
     regexp = NA
   )
@@ -54,7 +56,7 @@ test_that('model fitting', {
         basic_mod,
         control = ctrl,
         x = tr_dat[, -5],
-        y = tr_dat$Species
+        y = tr_dat$class
       ),
     regexp = NA
   )
@@ -64,7 +66,7 @@ test_that('model fitting', {
   expect_error(
     fit(
       basic_mod,
-      Species ~ .,
+      class ~ .,
       data = tr_dat,
       control = ctrl
     ),
@@ -77,7 +79,7 @@ test_that('model fitting', {
         reg_mod,
         control = ctrl,
         x = tr_dat[, -5],
-        y = tr_dat$Species
+        y = tr_dat$class
       ),
     regexp = NA
   )
@@ -85,7 +87,7 @@ test_that('model fitting', {
   expect_error(
     fit(
       reg_mod,
-      Species ~ .,
+      class ~ .,
       data = tr_dat,
       control = ctrl
     ),
@@ -107,7 +109,7 @@ test_that('classification prediction', {
       basic_mod,
       control = ctrl,
       x = tr_dat[, -5],
-      y = tr_dat$Species
+      y = tr_dat$class
     )
 
   keras_raw <-
@@ -125,7 +127,7 @@ test_that('classification prediction', {
       reg_mod,
       control = ctrl,
       x = tr_dat[, -5],
-      y = tr_dat$Species
+      y = tr_dat$class
     )
 
   keras_raw <-
@@ -151,7 +153,7 @@ test_that('classification probabilities', {
       basic_mod,
       control = ctrl,
       x = tr_dat[, -5],
-      y = tr_dat$Species
+      y = tr_dat$class
     )
 
   keras_pred <-
@@ -168,7 +170,7 @@ test_that('classification probabilities', {
       reg_mod,
       control = ctrl,
       x = tr_dat[, -5],
-      y = tr_dat$Species
+      y = tr_dat$class
     )
 
   keras_pred <-
